@@ -14,6 +14,7 @@
 #include "confgen.hpp"
 
 using namespace std;
+using namespace boost::spirit;
 
 static const char* version = CONF4CPP_VERSION;
 static const char* program = "conf4cpp";
@@ -85,7 +86,7 @@ int main(int argc, char* argv[])
     ofstream ofs_hpp(tmp_hpp);
     ofstream ofs_cpp(tmp_cpp);
 
-    confgen::output_interface_header(ofs_hpp);
+    confgen::output_interface_header(ofs_hpp, interface_file_name);
     confgen::output_implementation_header(ofs_cpp, interface_file_name);
 
     while (optind < argc) {
@@ -111,7 +112,7 @@ int main(int argc, char* argv[])
                 fprintf(stderr, "%s: %d: parse error\n", input_file, pinfo.stop.get_position().line);
                 goto error_return;
             }
-        } catch (boost::spirit::parser_error<string,position_iterator_t>& e) {
+        } catch (const parser_error<string,position_iterator_t>& e) {
             fprintf(stderr, "%s: %d: %s\n", input_file, e.where.get_position().line, e.descriptor.c_str());
             goto error_return;
         }
@@ -120,6 +121,8 @@ int main(int argc, char* argv[])
         gen.output_interface(ofs_hpp);
         gen.output_implementation(ofs_cpp);
     }
+    confgen::output_interface_footer(ofs_hpp);
+    confgen::output_implementation_footer(ofs_cpp);
 
     if (rename(tmp_hpp, interface_file_name.c_str()) < 0) {
         fprintf(stderr, "cannot create %s\n", interface_file_name.c_str());
