@@ -33,8 +33,10 @@ int main(int argc, char* args[])
 	return -1;
     }
 
-    test_conf conf(args[1]);
-
+    test::inner_test::test_conf conf(args[1]);
+    assert(conf.int_val()==-123);
+    assert(conf.bool_val()==false);
+    assert(conf.week_val()==test::inner_test::test_conf::SUN);
     assert(!conf.has_string_val());
     assert(conf.has_real_val());
     assert(conf.real_val()==-32134.5643);
@@ -42,9 +44,21 @@ int main(int argc, char* args[])
     assert(conf.string_list()[0]=="foo");
     assert(conf.string_list()[1]=="bar");
     assert(conf.string_list()[2]=="baz");
+    vector<string> string0_list_val(1,"foo");
+    assert(conf.set_string0_list(string0_list_val)==false); 
     assert(conf.string0_list().size()==0);
+    vector<int> int1_list_val(5);
+    assert(conf.set_int1_list(int1_list_val)==false);
     assert(conf.int1_list().size()==1);
     assert(conf.int1_list()[0]==10);
+    vector<int> int1_list_val2;
+    int1_list_val2.push_back(3);
+    assert(conf.set_int1_list(int1_list_val2)==true);
+    assert(conf.int1_list().size()==1);
+    assert(conf.int1_list()[0]==3);
+    assert(conf.set("int1_list={1}")==true);
+    assert(conf.int1_list().size()==1);
+    assert(conf.int1_list()[0]==1);
     assert(conf.bool9_list().size()==9);
     assert(conf.bool9_list()[8]==true);
     assert(conf.real_llist().size()==5);
@@ -55,9 +69,9 @@ int main(int argc, char* args[])
     assert(boost::get<1>(conf.rib_tuple())==5);
     assert(boost::get<2>(conf.rib_tuple())==true);
     assert(boost::get<0>(boost::get<0>(conf.string_tuple()))=="hoge");
-    assert(boost::get<0>(conf.week_fruits())==test_conf::MON);
+    assert(boost::get<0>(conf.week_fruits())==test::inner_test::test_conf::MON);
     assert(boost::get<1>(conf.week_fruits()).size()==4);
-    assert(boost::get<1>(conf.week_fruits())[0]==test_conf::Apple);
+    assert(boost::get<1>(conf.week_fruits())[0]==test::inner_test::test_conf::Apple);
 
     assert(!conf.has_int_defval());
     assert(!conf.has_int_defval2());
@@ -119,6 +133,58 @@ int main(int argc, char* args[])
     assert(ipv6_equal(ipv6,conf.ipv6_value6()));
     inet_pton(AF_INET6, "1:2:3:4:5:6:7:8", &ipv6);
     assert(ipv6_equal(ipv6,conf.ipv6_value7()));
+    // test set method
+    conf.set_int_val(321);
+    assert(conf.int_val()==321);
+    assert(conf.string_val()=="");
+    conf.set_string_val("hoge");
+    assert(conf.string_val()=="hoge");
+    assert(conf.set_uint_ranval3(123)==true);
+    assert(conf.uint_ranval3()==123);
+    assert(conf.set_uint_ranval3(11)==false);
+    assert(conf.uint_ranval3()==123);
+    vector<tuple<string,int> > stri_list_def_val;    
+    assert(conf.set_stri_list_def(stri_list_def_val)==false);
+    assert(conf.stri_list_def().size()==3);
+    // test general setter
+    assert(conf.set("uint_ranval3 = 200;")==true);
+    assert(conf.uint_ranval3()==200);
+    assert(conf.set("uint_ranval3 = 150; string_val = \"foo\"")==true);
+    assert(conf.uint_ranval3()==150);
+    assert(conf.string_val()=="foo");
+    assert(conf.set("int_val=1;")==true);
+    assert(conf.int_val()==1);
+    // 範囲外のデータはセットできない
+    assert(conf.set("uint_ranval3 = 0; int_val=-123;")==false);
+    assert(conf.uint_ranval3()==150);
+    assert(conf.int_val()==1);
+    // const項目はsetできない
+    assert(conf.set("ipv4_value=1.2.3.4")==false);
+    assert(conf.ipv4_value().s_addr==0);
+    // default値のチェック
+    assert(conf.int_ranval4()==3);
+    assert(conf.int_ranval5()==0);
+    assert(conf.int_ranval6()==-10);
+    // range_vals: real[32.5~100.3],uint[100 ~ ],int[~-10] = 32.5, 100, -30;
+    assert(boost::get<0>(conf.range_vals())==32.5);
+    assert(boost::get<1>(conf.range_vals())==100);
+    assert(boost::get<2>(conf.range_vals())==-30);
+    assert(conf.set_range_vals(boost::make_tuple(double(0.0),(unsigned int)100,int(-20)))==false);
+    // ranval_list:list[2]<int[-10~10]>
+    {
+    vector<int> ranval_list_val = conf.ranval_list();
+    assert(ranval_list_val.size()==2);
+    assert(ranval_list_val[0] = 3);
+    assert(ranval_list_val[1] = -4);
+    ranval_list_val[1] = 100;
+	// 配列要素の範囲違反
+    assert(conf.set_ranval_list(ranval_list_val)==false);
+    }
+    {
+	// 配列の長さが違反
+    vector<int> ranval_list_val(3);
+    assert(conf.set_ranval_list(ranval_list_val)==false);
+    }
 
     conf.dump(cout);
 
